@@ -1,4 +1,5 @@
 #' Replicate expression and return results in a list.
+#'
 #' Evalulate expression n times then combine results into a list
 #' 
 #' This function runs an expression multiple times, and combines the 
@@ -33,7 +34,7 @@ rlply <- function(.n, .expr, .progress = "none") {
   on.exit(progress$term())
 
   for(i in seq_len(.n)) {
-    result[[i]] <- f()
+    result[i] <- list(f())
     progress$step()
   }
   
@@ -41,6 +42,7 @@ rlply <- function(.n, .expr, .progress = "none") {
 }
 
 #' Replicate expression and return results in a data frame.
+#'
 #' Evalulate expression n times then combine results into a data frame
 #' 
 #' This function runs an expression multiple times, and combines the 
@@ -77,6 +79,7 @@ rdply <- function(.n, .expr, .progress = "none") {
 
 
 #' Replicate expression and return results in a array.
+#'
 #' Evalulate expression n times then combine results into an array
 #' 
 #' This function runs an expression multiple times, and combines the 
@@ -118,6 +121,7 @@ raply <- function(.n, .expr, .progress = "none", .drop = TRUE) {
 }
 
 #' Replicate expression and discard results.
+#'
 #' Evalulate expression n times then discard results
 #' 
 #' This function runs an expression multiple times, discarding the results. 
