@@ -20,7 +20,7 @@ test_that("empty lists return an empty object", {
 
 test_that("empty data frames returns empty object", {
   df <- data.frame(x = numeric(0), a = numeric(0))
-  expect_that(ddply(df, "a", identity), equals(data.frame()))
+  expect_that(ddply(df, "a", identity), equals(df))
   expect_that(dlply(df, "a", identity), equals(list()))
   expect_that(daply(df, "a", identity), equals(logical()))
 })
